.. _dataset-autodoc:

#########
 Dataset
#########

.. autoclass:: anemoi.datasets.data.dataset.Dataset
   :members: dates, latitudes, longitudes, dates_interval_to_indices, provenance, typed_variables, metadata, start_date, end_date, supporting_arrays, grids, variables, frequency, name_to_index, shape, field_shape, dtype, missing, statistics,statistics_tendencies
